@@ -1,20 +1,20 @@
 from __future__ import absolute_import
-# Copyright (c) 2010-2017 openpyxl
+# Copyright (c) 2010-2018 openpyxl
 
 import pytest
 
+import datetime
 from io import BytesIO
 from zipfile import ZipFile
 
 from lxml.etree import iterparse, fromstring
 
-from openpyxl.utils.exceptions import InvalidFileException
 from openpyxl import load_workbook
 from openpyxl.compat import unicode
 from openpyxl.xml.constants import SHEET_MAIN_NS
-from openpyxl.cell import Cell
 from openpyxl.utils.indexed_list import IndexedList
 from openpyxl.worksheet import Worksheet
+from openpyxl.worksheet.pagebreak import Break, PageBreak
 from openpyxl.packaging.relationship import Relationship, RelationshipList
 
 
@@ -45,15 +45,12 @@ def test_get_xml_iter():
     z.writestr("test", "whatever")
     stream = FUT(z.open("test"))
     assert hasattr(stream, "read")
-    # z.close()
+
     try:
         z.close()
     except IOError:
         # you can't just close zipfiles in Windows
-        if z.fp is not None:
-            z.fp.close() # python 2.6
-        else:
-            z.close() # python 2.7
+        z.close() # python 2.7
 
 
 @pytest.fixture
@@ -131,7 +128,7 @@ def test_col_width(datadir, WorkSheetParser):
         cols = iterparse(src, tag='{%s}col' % SHEET_MAIN_NS)
         for _, col in cols:
             parser.parse_column_dimensions(col)
-    assert set(ws.column_dimensions.keys()) == set(['A', 'C', 'E', 'I', 'G'])
+    assert set(ws.column_dimensions) == set(['A', 'C', 'E', 'I', 'G'])
     assert ws.column_dimensions['A'].style_id == 0
     assert dict(ws.column_dimensions['A']) == {'max': '1', 'min': '1',
                                                'customWidth': '1',
@@ -301,6 +298,23 @@ def test_number(WorkSheetParser):
     assert ws['A1'].value == 1
 
 
+
+def test_datetime(WorkSheetParser):
+    parser = WorkSheetParser
+    ws = parser.ws
+
+    src = """
+    <x:c r="A1" t="d" xmlns:x="http://schemas.openxmlformats.org/spreadsheetml/2006/main">
+        <x:v>2011-12-25T14:23:55</x:v>
+    </x:c>
+    """
+    element = fromstring(src)
+
+    parser.parse_cell(element)
+    assert ws['A1'].data_type == 'd'
+    assert ws['A1'].value == datetime.datetime(2011, 12, 25, 14, 23, 55)
+
+
 def test_string(WorkSheetParser):
     parser = WorkSheetParser
     ws = parser.ws
@@ -504,19 +518,19 @@ def test_shared_formulae(WorkSheetParser, datadir):
 
     parser.parse()
 
-    assert set(ws.formula_attributes.keys()) == set(['C10'])
+    assert set(ws.formula_attributes) == set(['C10'])
 
     # Test shared forumlae
-    assert ws.cell('B7').data_type == 'f'
-    assert ws.cell('B7').value == '=B4*2'
-    assert ws.cell('C7').value == '=C4*2'
-    assert ws.cell('D7').value == '=D4*2'
-    assert ws.cell('E7').value == '=E4*2'
+    assert ws['B7'].data_type == 'f'
+    assert ws['B7'].value == '=B4*2'
+    assert ws['C7'].value == '=C4*2'
+    assert ws['D7'].value == '=D4*2'
+    assert ws['E7'].value == '=E4*2'
 
     # Test array forumlae
-    assert ws.cell('C10').data_type == 'f'
+    assert ws['C10'].data_type == 'f'
     assert ws.formula_attributes['C10']['ref'] == 'C10:C14'
-    assert ws.cell('C10').value == '=SUM(A10:A14*B10:B14)'
+    assert ws['C10'].value == '=SUM(A10:A14*B10:B14)'
 
 
 def test_cell_without_coordinates(WorkSheetParser, datadir):
@@ -589,7 +603,7 @@ def test_merge_cells(WorkSheetParser):
 
     parser.parse()
 
-    assert parser.ws._merged_cells == ["C2:F2", "B19:C20", "E19:G19"]
+    assert parser.ws.merged_cells == "C2:F2 B19:C20 E19:G19"
 
 
 def test_conditonal_formatting(WorkSheetParser):
@@ -612,7 +626,7 @@ def test_conditonal_formatting(WorkSheetParser):
 
     parser.parse()
 
-    assert parser.ws.conditional_formatting.cf_rules['T1:T10'][-1].dxf == dxf
+    assert parser.ws.conditional_formatting['T1:T10'][-1].dxf == dxf
 
 
 def test_sheet_properties(WorkSheetParser):
@@ -707,3 +721,22 @@ def test_sort_state(WorkSheetParser):
     ws = parser.ws
 
     assert ws.sort_state.ref == "A2:AM3269"
+
+
+def test_page_break(WorkSheetParser):
+    src = """
+    <sheet xmlns="http://schemas.openxmlformats.org/spreadsheetml/2006/main">
+        <rowBreaks count="1" manualBreakCount="1">
+            <brk id="15" man="1" max="16383" min="0"/>
+        </rowBreaks>
+    </sheet>
+    """
+    expected_pagebreak = PageBreak()
+    expected_pagebreak.append(Break(id=15))
+
+    parser = WorkSheetParser
+    parser.source = src
+    parser.parse()
+    ws = parser.ws
+
+    assert ws.page_breaks == expected_pagebreak
