@@ -1,5 +1,5 @@
 from __future__ import absolute_import
-# Copyright (c) 2010-2016 openpyxl
+# Copyright (c) 2010-2018 openpyxl
 
 import re
 
@@ -157,7 +157,7 @@ class CustomFilter(Serialisable):
 
     tagname = "customFilter"
 
-    operator = Set(values=(['equal', 'lessThan', 'lessThanOrEqual',
+    operator = NoneSet(values=(['equal', 'lessThan', 'lessThanOrEqual',
                             'notEqual', 'greaterThanOrEqual', 'greaterThan']))
     val = String()
 
